@@ -7,12 +7,13 @@ from email_helper.models import Email
 
 
 class EmailAdmin(admin.ModelAdmin):
-    list_display = ('when', 'whom', 'subject', 'status')
-    readonly_fields = ('_body',)
-    fieldsets = (
-        (None, {'fields': ('when', 'whom', 'subject', 'status')}),
-        (None, {'fields': ('_body',)}),
-    )
+    list_display = ['when', 'whom', 'subject', 'status']
+    search_fields = ['whom', 'subject']
+    readonly_fields = ['_body']
+    fieldsets = [
+        [None, {'fields': ['when', 'whom', 'subject', 'status']}],
+        [None, {'fields': ['_body']}],
+    ]
 
     def _body(self, obj):
         return obj.body
